import { __awaiter, __decorate } from "tslib";
import { GenesisResources } from '@genesislcap/foundation-comms';
import { LifecycleMixin } from '@genesislcap/foundation-utils';
import { customElement, DOM, GenesisElement, html, ref } from '@genesislcap/web-core';
import { Store } from '../../../store';
let ResourcesGrid = class ResourcesGrid extends LifecycleMixin(GenesisElement) {
    connectedCallback() {
        const _super = Object.create(null, {
            connectedCallback: { get: () => super.connectedCallback }
        });
        return __awaiter(this, void 0, void 0, function* () {
            _super.connectedCallback.call(this);
            if (!this.shouldRunConnect)
                return;
            const resources = yield this.resources.getAllResources();
            const gridOptions = {
                suppressRowTransform: true,
                rowSelection: 'single',
                defaultColDef: {
                    resizable: true,
                    filter: true,
                },
                columnDefs: [
                    { headerName: 'Name', field: 'RESOURCE_NAME' },
                    { headerName: 'Type', field: 'RESOURCE_TYPE' },
                ],
                rowData: resources,
                onRowSelected: (event) => {
                    DOM.queueUpdate(() => {
                        var _a;
                        const selectedRows = (_a = event.api) === null || _a === void 0 ? void 0 : _a.getSelectedRows();
                        if (!selectedRows || selectedRows.length === 0) {
                            this.store.emitSelectedResourceData(null);
                            return;
                        }
                        this.store.emitSelectedResourceData(selectedRows[0]);
                    });
                },
            };
            this.resourcesGrid.gridOptions = gridOptions;
        });
    }
};
__decorate([
    Store
], ResourcesGrid.prototype, "store", void 0);
__decorate([
    GenesisResources
], ResourcesGrid.prototype, "resources", void 0);
ResourcesGrid = __decorate([
    customElement({
        name: 'resources-grid',
        template: html `
    <rapid-grid-pro grid-autosizing ${ref('resourcesGrid')}></rapid-grid-pro>
  `,
    })
], ResourcesGrid);
export { ResourcesGrid };
