import { __awaiter, __decorate, __param } from "tslib";
import { Auth } from '@genesislcap/foundation-comms';
import { FoundationRouterConfiguration } from '@genesislcap/foundation-ui';
import { defaultLayout, loginLayout } from '../layouts';
import { backgroundConsoleApp } from '../styles';
/**
 * Base implementation of a routing used with the Login class
 *
 * @remarks
 *
 * Could be used when using the Login class as a standalone authentication method
 * with your app
 *
 * @internal
 */
let MainRouterConfig = class MainRouterConfig extends FoundationRouterConfiguration {
    constructor(auth) {
        super();
        this.auth = auth;
    }
    configure() {
        this.title = 'Console Micro Frontend';
        this.defaultLayout = defaultLayout;
        this.routes.map({
            path: '',
            name: 'auth',
            title: 'Login',
            element: () => __awaiter(this, void 0, void 0, function* () {
                const { configure, define } = yield import(
                /* webpackChunkName: "foundation-login" */
                '@genesislcap/foundation-login');
                configure(this.container, {
                    background: backgroundConsoleApp,
                    defaultRedirectUrl: 'console-demo',
                });
                /**
                 * You can import and return `Login` directly:
                 * return Login;
                 *
                 * ...or re-define it to suit your app needs first.
                 */
                return define({
                    name: `console-login`,
                });
            }),
            layout: loginLayout,
            settings: { public: true },
            childRouters: true,
        }, {
            path: 'console-demo',
            element: () => __awaiter(this, void 0, void 0, function* () { return (yield import('./demo/console')).FoundationConsoleDemo; }),
            title: 'Console Demo',
            name: 'console-demo',
            settings: { autoAuth: true },
        });
        /**
         * Example of a NavigationContributor
         */
        this.contributors.push({
            navigate: (phase) => __awaiter(this, void 0, void 0, function* () {
                const settings = phase.route.settings;
                /**
                 * If the route is public or the user is authenticated don't block
                 */
                if ((settings === null || settings === void 0 ? void 0 : settings.public) || this.user.isAuthenticated) {
                    return;
                }
                /**
                 * If autoAuth and session is valid try to connect+auto-login
                 */
                if (settings && settings.autoAuth && (yield this.auth.reAuthFromSession())) {
                    return;
                }
                /**
                 * Otherwise route them to login
                 */
                this.navigationPhaseLoginRedirect(phase);
            }),
        });
    }
};
MainRouterConfig = __decorate([
    __param(0, Auth)
], MainRouterConfig);
export { MainRouterConfig };
